@@ -21,7 +21,6 @@
 
 #include <string.h>
 #include <gio/gio.h>
-#include <pluma/pluma-plugin.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -86,7 +85,7 @@ static const GtkTargetEntry drag_source_targets[] = {
 	{ "text/uri-list", 0, 0 }
 };
 
-PLUMA_PLUGIN_DEFINE_TYPE (PlumaFileBrowserView, pluma_file_browser_view,
+G_DEFINE_DYNAMIC_TYPE (PlumaFileBrowserView, pluma_file_browser_view,
 	                  GTK_TYPE_TREE_VIEW)
 
 static void on_cell_edited 		(GtkCellRendererText 	* cell, 
@@ -114,11 +113,7 @@ pluma_file_browser_view_finalize (GObject * object)
 	PlumaFileBrowserView *obj = PLUMA_FILE_BROWSER_VIEW(object);
 	
 	if (obj->priv->hand_cursor)
-#if GTK_CHECK_VERSION (3, 0, 0)
 		g_object_unref (obj->priv->hand_cursor);
-#else
-		gdk_cursor_unref (obj->priv->hand_cursor);
-#endif
 
 	if (obj->priv->hover_path)
 		gtk_tree_path_free (obj->priv->hover_path);
@@ -129,11 +124,7 @@ pluma_file_browser_view_finalize (GObject * object)
 		obj->priv->expand_state = NULL;
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_object_unref (obj->priv->busy_cursor);
-#else
-	gdk_cursor_unref (obj->priv->busy_cursor);
-#endif
 
 	G_OBJECT_CLASS (pluma_file_browser_view_parent_class)->
 	    finalize (object);
@@ -312,16 +303,13 @@ set_click_policy_property (PlumaFileBrowserView            *obj,
 	GdkDisplay *display;
 	GdkWindow *win;
 
+	display = gtk_widget_get_display (GTK_WIDGET (obj));
+
 	obj->priv->click_policy = click_policy;
 
 	if (click_policy == PLUMA_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE) {
 		if (obj->priv->hand_cursor == NULL)
-#if GTK_CHECK_VERSION (3, 16, 0)
-			display = gtk_widget_get_display (GTK_WIDGET (obj));
 			obj->priv->hand_cursor = gdk_cursor_new_for_display (display, GDK_HAND2);
-#else
-			obj->priv->hand_cursor = gdk_cursor_new(GDK_HAND2);
-#endif
 	} else if (click_policy == PLUMA_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE) {
 		if (obj->priv->hover_path != NULL) {
 			if (gtk_tree_model_get_iter (GTK_TREE_MODEL (obj->priv->model),
@@ -344,11 +332,7 @@ set_click_policy_property (PlumaFileBrowserView            *obj,
 		}
 
 		if (obj->priv->hand_cursor) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_object_unref (obj->priv->hand_cursor);
-#else
-			gdk_cursor_unref (obj->priv->hand_cursor);
-#endif
 			obj->priv->hand_cursor = NULL;
 		}
 	}
@@ -927,6 +911,12 @@ pluma_file_browser_view_class_init (PlumaFileBrowserViewClass * klass)
 				  sizeof (PlumaFileBrowserViewPrivate));
 }
 
+static void
+pluma_file_browser_view_class_finalize (PlumaFileBrowserViewClass *klass)
+{
+	/* dummy function - used by G_DEFINE_DYNAMIC_TYPE */
+}
+
 static void
 cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
 	      GtkTreeModel * tree_model, GtkTreeIter * iter,
@@ -962,9 +952,8 @@ cell_data_cb (GtkTreeViewColumn * tree_column, GtkCellRenderer * cell,
 static void
 pluma_file_browser_view_init (PlumaFileBrowserView * obj)
 {
-#if GTK_CHECK_VERSION (3, 16, 0)
 	GdkDisplay *display;
-#endif
+
 	obj->priv = PLUMA_FILE_BROWSER_VIEW_GET_PRIVATE (obj);
 
 	obj->priv->column = gtk_tree_view_column_new ();
@@ -999,12 +988,8 @@ pluma_file_browser_view_init (PlumaFileBrowserView * obj)
 						G_N_ELEMENTS (drag_source_targets),
 						GDK_ACTION_COPY);
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 	display = gtk_widget_get_display (GTK_WIDGET (obj));
 	obj->priv->busy_cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
-#else
-	obj->priv->busy_cursor = gdk_cursor_new (GDK_WATCH);
-#endif
 }
 
 static gboolean
@@ -1278,5 +1263,11 @@ on_row_inserted (PlumaFileBrowserStore * model,
 
 	gtk_tree_path_free (copy);
 }
+
+void
+_pluma_file_browser_view_register_type (GTypeModule *type_module)
+{
+	pluma_file_browser_view_register_type (type_module);
+}
 				 
 // ex:ts=8:noet:
