@@ -48,22 +48,14 @@ gboolean (*PlumaFileBrowserWidgetFilterFunc) (PlumaFileBrowserWidget * obj,
 
 struct _PlumaFileBrowserWidget 
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkBox parent;
-#else
-	GtkVBox parent;
-#endif
 
 	PlumaFileBrowserWidgetPrivate *priv;
 };
 
 struct _PlumaFileBrowserWidgetClass 
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkBoxClass parent_class;
-#else
-	GtkVBoxClass parent_class;
-#endif
 
 	/* Signals */
 	void (*uri_activated)        (PlumaFileBrowserWidget * widget,
@@ -79,7 +71,7 @@ struct _PlumaFileBrowserWidgetClass
 };
 
 GType pluma_file_browser_widget_get_type            (void) G_GNUC_CONST;
-GType pluma_file_browser_widget_register_type       (GTypeModule * module);
+void _pluma_file_browser_widget_register_type       (GTypeModule * module);
 
 GtkWidget *pluma_file_browser_widget_new            (const gchar *data_dir);
 
