@@ -454,11 +454,7 @@ build_suggestion_menu (PlumaAutomaticSpellChecker *spell, const gchar *word)
 			
 			label = gtk_label_new (label_text);
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 			gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-			gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
 
 			mi = gtk_menu_item_new ();
 			gtk_container_add (GTK_CONTAINER(mi), label);
