@@ -25,7 +25,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <pluma/pluma-plugin.h>
+#include <libpeas/peas-extension-base.h>
+#include <libpeas/peas-object-module.h>
 
 G_BEGIN_DECLS
 
@@ -49,8 +50,9 @@ typedef struct _PlumaSpellPlugin	PlumaSpellPlugin;
 
 struct _PlumaSpellPlugin
 {
-	PlumaPlugin parent_instance;
+	PeasExtensionBase parent_instance;
 
+	/*< private >*/
 	PlumaSpellPluginPrivate *priv;
 };
 
@@ -61,7 +63,7 @@ typedef struct _PlumaSpellPluginClass	PlumaSpellPluginClass;
 
 struct _PlumaSpellPluginClass
 {
-	PlumaPluginClass parent_class;
+	PeasExtensionBaseClass parent_class;
 };
 
 /*
@@ -70,7 +72,7 @@ struct _PlumaSpellPluginClass
 GType	pluma_spell_plugin_get_type		(void) G_GNUC_CONST;
 
 /* All the plugins must implement this function */
-G_MODULE_EXPORT GType register_pluma_plugin (GTypeModule *module);
+G_MODULE_EXPORT void peas_register_types (PeasObjectModule *module);
 
 G_END_DECLS
 
