@@ -39,9 +39,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
 #include <gtksourceview/gtksource.h>
-#endif
 
 #include "pluma-file-chooser-dialog.h"
 #include "pluma-encodings-combo-box.h"
@@ -55,10 +53,6 @@
 #define ALL_FILES		_("All Files")
 #define ALL_TEXT_FILES		_("All Text Files")
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 struct _PlumaFileChooserDialogPrivate
 {
 	GtkWidget *option_menu;
@@ -86,11 +80,7 @@ create_option_menu (PlumaFileChooserDialog *dialog)
 	GtkWidget *menu;
 
 	label = gtk_label_new_with_mnemonic (_("C_haracter Encoding:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-#endif
 
 	menu = pluma_encodings_combo_box_new (
 		gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
@@ -155,11 +145,7 @@ create_newline_combo (PlumaFileChooserDialog *dialog)
 	GtkTreeIter iter;
 
 	label = gtk_label_new_with_mnemonic (_("L_ine Ending:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-#endif
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, PLUMA_TYPE_DOCUMENT_NEWLINE_TYPE);
 	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
@@ -216,7 +202,7 @@ create_newline_combo (PlumaFileChooserDialog *dialog)
 static void
 create_extra_widget (PlumaFileChooserDialog *dialog)
 {
-	dialog->priv->extra_widget = gtk_hbox_new (FALSE, 6);
+	dialog->priv->extra_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
 	gtk_widget_show (dialog->priv->extra_widget);
 
@@ -309,11 +295,7 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 			GtkSourceLanguage *lang;
 
 			lang = gtk_source_language_manager_get_language (lm, *languages);
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE (lang), FALSE);
-#else
-			g_return_val_if_fail (GTK_IS_SOURCE_LANGUAGE (lang), FALSE);
-#endif
 			++languages;
 
 			mime_types = gtk_source_language_get_mime_types (lang);
@@ -392,9 +374,6 @@ pluma_file_chooser_dialog_new_valist (const gchar          *title,
 
 	result = g_object_new (PLUMA_TYPE_FILE_CHOOSER_DIALOG,
 			       "title", title,
-#if !GTK_CHECK_VERSION (3, 0, 0)
-			       "file-system-backend", NULL,
-#endif
 			       "local-only", FALSE,
 			       "action", action,
 			       "select-multiple", action == GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -421,9 +400,7 @@ pluma_file_chooser_dialog_new_valist (const gchar          *title,
 	gtk_file_filter_set_name (filter, ALL_FILES);
 	gtk_file_filter_add_pattern (filter, "*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (result), filter);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_file_chooser_set_action (GTK_FILE_CHOOSER (result), action);
-#endif
 
 	if (active_filter != 1)
 	{
@@ -478,7 +455,7 @@ pluma_file_chooser_dialog_new_valist (const gchar          *title,
  * @action: Open or save mode for the dialog
  * @first_button_text: (allow-none): stock ID or text to go in
  * the first button, or %NULL
- * @Varargs: (allow-none): response ID for the first button, then
+ * @...: (allow-none): response ID for the first button, then
  * additional (button, id) pairs, ending with %NULL
  *
  * Creates a new #PlumaFileChooserDialog.  This function is analogous to
