@@ -56,6 +56,9 @@
 
 #define PLUMA_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PLUMA_TYPE_VIEW, PlumaViewPrivate))
 
+/* Local variables */
+static gboolean middle_or_right_down = FALSE;
+
 typedef enum
 {
 	GOTO_LINE,
@@ -121,8 +124,13 @@ static gboolean pluma_view_drag_drop		(GtkWidget        *widget,
 	      					 gint              x,
 	      					 gint              y,
 	      					 guint             timestamp);
+
 static gboolean	pluma_view_button_press_event	(GtkWidget        *widget,
 						 GdkEventButton   *event);
+static gboolean	pluma_view_button_release_event	(GtkWidget        *widget,
+						 GdkEventButton   *event);
+static void	pluma_view_populate_popup	(GtkTextView      *text_view,
+						 GtkWidget        *widget);
 
 static gboolean start_interactive_search	(PlumaView        *view);
 static gboolean start_interactive_goto_line	(PlumaView        *view);
@@ -206,6 +214,8 @@ pluma_view_class_init (PlumaViewClass *klass)
 	widget_class->drag_data_received = pluma_view_drag_data_received;
 	widget_class->drag_drop = pluma_view_drag_drop;
 	widget_class->button_press_event = pluma_view_button_press_event;
+	widget_class->button_release_event = pluma_view_button_release_event;
+	text_view_class->populate_popup = pluma_view_populate_popup;
 	klass->start_interactive_search = start_interactive_search;
 	klass->start_interactive_goto_line = start_interactive_goto_line;
 	klass->reset_searched_text = reset_searched_text;	
@@ -1987,6 +1997,17 @@ show_line_numbers_menu (GtkWidget      *view,
 static gboolean
 pluma_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
+	if ((event->button == 2) || (event->button == 3))
+	{
+		if (middle_or_right_down)
+		{
+			middle_or_right_down = FALSE;
+			return TRUE;
+		}
+		else
+			middle_or_right_down = TRUE;
+	}
+
 	if ((event->type == GDK_BUTTON_PRESS) && 
 	    (event->window == gtk_text_view_get_window (GTK_TEXT_VIEW (widget),
 						        GTK_TEXT_WINDOW_LEFT)))
@@ -2007,6 +2028,21 @@ pluma_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 	return GTK_WIDGET_CLASS (pluma_view_parent_class)->button_press_event (widget, event);
 }
 
+static gboolean
+pluma_view_button_release_event (GtkWidget *widget, GdkEventButton *event)
+{
+	if (event->button == 2)
+		middle_or_right_down = FALSE;
+
+	return GTK_WIDGET_CLASS (pluma_view_parent_class)->button_release_event (widget, event);
+}
+
+static void
+pluma_view_populate_popup (GtkTextView *text_view, GtkWidget *widget)
+{
+	middle_or_right_down = FALSE;
+}
+
 static void 	
 search_highlight_updated_cb (PlumaDocument *doc,
 			     GtkTextIter   *start,
